==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'تحديث كل عناوين URL',
	'actualiser_toutes_explication' => 'يمكنك إعادة حساب عناوين URL.
		إذا كان أحد العناوين قد تغير، يتم إنشاء سجل جديد (دون فقدان العناوين الموجودة ودون اي تأثير على العناوين المنشأة يدوياً).
', # MODIF

	// B
	'bouton_supprimer_url' => 'حذف هذا العنوان',

	// E
	'erreur_arbo_2_segments_max' => 'لا يمكن استخدام اكثر من قطعتي عنوان URL لاي عنصر',
	'erreur_config_url_forcee' => 'إعداد عناوين URL مفروض في ملف <tt>mes_options.php</tt>.',
	'explication_editer' => 'تتيح لك إدارة عناوين URL المتطورة تحرير عناوين صفحات اي عنصر تحريري وإنتاج سرد لتطورها.',

	// I
	'icone_configurer_urls' => 'إعداد عناوين URL',
	'icone_controler_urls' => 'عناوين URL ذات معنى ',
	'info_1_url' => 'عنوان واحد',
	'info_id_parent' => 'parent#',
	'info_nb_urls' => '@nb@ عنوان',
	'info_objet' => 'عنصر',

	// L
	'label_tri_date' => 'التاريخ',
	'label_tri_id' => 'رقم التسلسل',
	'label_tri_url' => 'عنوان URL',
	'label_url' => 'عنوان URL جديد',
	'label_url_minuscules_0' => 'الحفاظ على حجم أحرف العنوان',
	'label_url_minuscules_1' => 'فرض العناوين بالأحرف الصغيرة',
	'label_url_permanente' => 'إقفال هذا العنوان (لا تحديث بعد تحرير العنصر)',
	'label_url_sep_id' => 'حرف لفصل الرقم المضاف في حال التكرار',
	'label_urls_activer_controle_oui' => 'تفعيل ادارة العناوين المتطورة',
	'label_urls_nb_max_car' => 'العدد الاقصى للأحرف',
	'label_urls_nb_min_car' => 'العدد الأدنى للأحرف',
	'liberer_url' => 'إلغاء القفل',
	'liste_des_urls' => 'كل عناوين URL',

	// T
	'texte_type_urls' => 'يمكنك اختيار أسلوب حساب عناوين الصفحات.',
	'texte_type_urls_attention' => 'تنبيه، لن يعمل هذا الاعداد الا اذا كان ملف @htaccess@ مثبتاً بشكل سليم في أصل الموقع.',
	'texte_urls_nb_max_car' => 'اذا كان العنوان أطول، سيتم بتره',
	'texte_urls_nb_min_car' => 'اذا كان العنوان أقصر، سيتم استخدام رقم تسلسله.',
	'titre_gestion_des_urls' => 'إدارة عناوين URL',
	'titre_type_arbo' => 'عناوين هرمية',
	'titre_type_html' => 'عناوين عناصر HTML',
	'titre_type_libres' => 'عناوين حرة',
	'titre_type_page' => 'عناوين صفحة',
	'titre_type_propres' => 'عناوين نظيفة',
	'titre_type_propres2' => 'عناوين نظيفة+<tt>.html</tt>',
	'titre_type_propres_qs' => 'عناوين نظيفة باستفسار query-string',
	'titre_type_simple' => 'عناوين بسيطة',
	'titre_type_standard' => 'عناوين تاريخية',
	'titre_type_urls' => 'نوع عناوين URL',
	'tout_voir' => 'عرض كل عناوين URL',

	// U
	'url_ajout_impossible' => 'حصل خطأ. لم يتم تسجيل هذا العنوان',
	'url_ajoutee' => 'تمت إضافة هذا العنوان',

	// V
	'verifier_url_nettoyee' => 'تم تصحيح العنوان، يمكنك التأكد قبل تسجيله.',
	'verrouiller_url' => 'إقفال'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/urls_etendues/lang/urls_ar.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/urls?lang_cible=ar
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'تحديث كل عناوين URL',
	'actualiser_toutes_explication' => 'يمكن إعادة حساب عناوين URL.
		إذا كان أحد العناوين قد تغير، يتم إنشاء سجل جديد (دون فقدان العناوين الموجودة ودون اي تأثير على العناوين المنشأة يدوياً).
',

	// B
	'bouton_supprimer_url' => 'حذف هذا العنوان',

	// E
	'erreur_arbo_2_segments_max' => 'لا يمكن استخدام اكثر من قطعتي عنوان URL لاي عنصر',
	'erreur_config_url_forcee' => 'إعداد عناوين URL مفروض في ملف <tt>mes_options.php</tt>.',
	'explication_editer' => 'تتيح لك إدارة عناوين URL المتطورة تحرير عناوين صفحات اي عنصر تحريري وإنتاج سرد لتطورها.',

	// I
	'icone_configurer_urls' => 'إعداد عناوين URL',
	'icone_controler_urls' => 'عناوين URL ذات معنى ',
	'info_1_url' => 'عنوان واحد',
	'info_id_parent' => 'parent#',
	'info_nb_urls' => '@nb@ عنوان',
	'info_objet' => 'عنصر',

	// L
	'label_tri_date' => 'التاريخ',
	'label_tri_id' => 'رقم التسلسل',
	'label_tri_url' => 'عنوان URL',
	'label_url' => 'عنوان URL جديد',
	'label_url_minuscules_0' => 'الحفاظ على حجم أحرف العنوان',
	'label_url_minuscules_1' => 'فرض العناوين بالأحرف الصغيرة',
	'label_url_permanente' => 'إقفال هذا العنوان (لا تحديث بعد تحرير العنصر)',
	'label_url_sep_id' => 'حرف لفصل الرقم المضاف في حال التكرار',
	'label_urls_activer_controle_oui' => 'تفعيل ادارة العناوين المتطورة',
	'label_urls_nb_max_car' => 'العدد الاقصى للأحرف',
	'label_urls_nb_min_car' => 'العدد الأدنى للأحرف',
	'liberer_url' => 'إلغاء القفل',
	'liste_des_urls' => 'كل عناوين URL',

	// T
	'texte_type_urls' => 'يمكنك اختيار أسلوب حساب عناوين الصفحات.',
	'texte_type_urls_attention' => 'تنبيه، لن يعمل هذا الاعداد الا اذا كان ملف @htaccess@ مثبتاً بشكل سليم في أصل الموقع.',
	'texte_urls_nb_max_car' => 'اذا كان العنوان أطول، سيتم بتره',
	'texte_urls_nb_min_car' => 'اذا كان العنوان أقصر، سيتم استخدام رقم تسلسله.',
	'titre_gestion_des_urls' => 'إدارة عناوين URL',
	'titre_type_arbo' => 'عناوين هرمية',
	'titre_type_html' => 'عناوين عناصر HTML',
	'titre_type_libres' => 'عناوين حرة',
	'titre_type_page' => 'عناوين صفحة',
	'titre_type_propres' => 'عناوين نظيفة',
	'titre_type_propres2' => 'عناوين نظيفة+<tt>.html</tt>',
	'titre_type_propres_qs' => 'عناوين نظيفة باستفسار query-string',
	'titre_type_simple' => 'عناوين بسيطة',
	'titre_type_standard' => 'عناوين تاريخية',
	'titre_type_urls' => 'نوع عناوين URL',
	'tout_voir' => 'عرض كل عناوين URL',

	// U
	'url_ajout_impossible' => 'حصل خطأ. لم يتم تسجيل هذا العنوان',
	'url_ajoutee' => 'تمت إضافة هذا العنوان',

	// V
	'verifier_url_nettoyee' => 'تم تصحيح العنوان، يمكنك التأكد قبل تسجيله.',
	'verrouiller_url' => 'إقفال'
);

?>
